@@ -6,7 +6,8 @@ def print_results(it: RowIterator, format_args: dict = None):
     if format_args is None:
         format_args = {
             "tablefmt": "pretty",
-            "missingval": "null"
+            "missingval": "null",
+            "stralign": 'right',
         }
     headers = {field.name: field.name for field in it.schema}
     rows = list(it)
